Learn R Programming

cheem (version 0.4.2)

as_logical_index: Assure a full length logical index

Description

Suggests a alpha opacity to plot with as a function of the number of observation.

Usage

as_logical_index(index, n)

Value

A logical index of length n.

Arguments

index

A vector, typically a numeric row index of the data to coerce to a logical index.

n

Single numeric, the number of rows of the data use as a replicate return length.

See Also

Other cheem utility: color_scale_of(), contains_nonnumeric(), is_discrete(), is_diverging(), linear_tform(), logistic_tform(), problem_type(), sug_basis(), sug_manip_var()

Examples

Run this code
library(cheem)

## Coerce a numeric index to logical
as_logical_index(c(1, 4:10, 15), nrow(mtcars))

## Logical indexs are unchanged
as_logical_index(mtcars$mpg > 30, nrow(mtcars))

Run the code above in your browser using DataLab