powered by
Suggests a alpha opacity to plot with as a function of the number of observation.
as_logical_index(index, n)
A logical index of length n.
A vector, typically a numeric row index of the data to coerce to a logical index.
Single numeric, the number of rows of the data use as a replicate return length.
Other cheem utility: color_scale_of(), contains_nonnumeric(), is_discrete(), is_diverging(), linear_tform(), logistic_tform(), problem_type(), sug_basis(), sug_manip_var()
color_scale_of()
contains_nonnumeric()
is_discrete()
is_diverging()
linear_tform()
logistic_tform()
problem_type()
sug_basis()
sug_manip_var()
library(cheem) ## Coerce a numeric index to logical as_logical_index(c(1, 4:10, 15), nrow(mtcars)) ## Logical indexs are unchanged as_logical_index(mtcars$mpg > 30, nrow(mtcars))
Run the code above in your browser using DataLab